/// <reference types="react" />
import { NotebookPanel, INotebookModel } from '@jupyterlab/notebook';
import { CommandRegistry } from '@lumino/commands';
import { DocumentRegistry } from '@jupyterlab/docregistry';
import { IRenderMime } from '@jupyterlab/rendermime-interfaces';
import { INotebookContent } from '@jupyterlab/nbformat';
import { ServiceManager, Kernel as JupyterKernel } from '@jupyterlab/services';
import { Lite, Kernel } from './../../jupyter';
import { ICellSidebarProps } from './cell/sidebar';
import { INotebookToolbarProps } from './toolbar/NotebookToolbar';
import { OnSessionConnection, KernelTransfer } from '../../state';
import './Notebook.css';
export type ExternalIPyWidgets = {
    name: string;
    version: string;
};
export type BundledIPyWidgets = ExternalIPyWidgets & {
    module: any;
};
export type IDatalayerNotebookExtensionProps = {
    notebookId: string;
    commands: CommandRegistry;
};
export type DatalayerNotebookExtension = DocumentRegistry.IWidgetExtension<NotebookPanel, INotebookModel> & {
    init(props: IDatalayerNotebookExtensionProps): void;
    get component(): JSX.Element | undefined;
};
export type INotebookProps = {
    CellSidebar?: (props: ICellSidebarProps) => JSX.Element;
    Toolbar?: (props: INotebookToolbarProps) => JSX.Element;
    cellMetadataPanel: boolean;
    cellSidebarMargin: number;
    extensions: DatalayerNotebookExtension[];
    height?: string;
    id: string;
    kernel?: Kernel;
    kernelClients?: JupyterKernel.IKernelConnection[];
    kernelTransfer?: KernelTransfer;
    lite?: Lite;
    maxHeight?: string;
    nbformat?: INotebookContent;
    nbgrader: boolean;
    onSessionConnection?: OnSessionConnection;
    path?: string;
    readonly: boolean;
    renderId: number;
    renderers: IRenderMime.IRendererFactory[];
    serverless: boolean;
    serviceManager?: ServiceManager.IManager;
    startDefaultKernel?: boolean;
    url?: string;
    /**
     * The Kernel Id to use, as defined in the Kernel API.
     */
    useRunningKernelId?: string;
    /**
     * The index (aka position) of the Kernel to use in the list of kernels.
     */
    useRunningKernelIndex?: number;
};
/**
 * This component creates a Notebook as a collection of cells
 * with sidebars.
 *
 * @param props The notebook properties.
 * @returns A Notebook React.js component.
 */
export declare const Notebook: {
    (props: INotebookProps): import("react/jsx-runtime").JSX.Element;
    defaultProps: Partial<INotebookProps>;
};
export default Notebook;
